summaryrefslogtreecommitdiffstats
path: root/src/shortcuts.cpp
diff options
context:
space:
mode:
authorAndrey Mozzhuhin <amozzhuhin@yandex.ru>2017-10-05 21:46:14 +0000
committerAndrey Mozzhuhin <amozzhuhin@yandex.ru>2017-10-05 21:46:14 +0000
commit525c6c0c7ea39c6bdb0013c546d08b6e94e51e61 (patch)
tree2d9ba73efbc0d92bf72a41211d502c6c198a9037 /src/shortcuts.cpp
parentFix bug #1226962 - Keyboard shortcuts (hotkeys) not functional in some (diff)
downloadinkscape-525c6c0c7ea39c6bdb0013c546d08b6e94e51e61.tar.gz
inkscape-525c6c0c7ea39c6bdb0013c546d08b6e94e51e61.zip
Rename get_group0_keyval to get_latin_keyval
Diffstat (limited to 'src/shortcuts.cpp')
-rw-r--r--src/shortcuts.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/shortcuts.cpp b/src/shortcuts.cpp
index c1677ca51..0a1e0c4a9 100644
--- a/src/shortcuts.cpp
+++ b/src/shortcuts.cpp
@@ -153,7 +153,7 @@ guint sp_shortcut_translate_event(GdkEventKey const *event, guint *effective_mod
guint remaining_modifiers = 0;
guint resulting_modifiers = 0; // remaining modifiers encoded in high-bit mask
- keyval = Inkscape::UI::Tools::get_group0_keyval(event, &consumed_modifiers);
+ keyval = Inkscape::UI::Tools::get_latin_keyval(event, &consumed_modifiers);
remaining_modifiers = initial_modifiers & ~consumed_modifiers;
resulting_modifiers = ( remaining_modifiers & GDK_SHIFT_MASK ? SP_SHORTCUT_SHIFT_MASK : 0 ) |
@@ -485,7 +485,7 @@ void sp_shortcut_file_export_do(char const *exportname) {
* Shortcut file consists of pairs of bind elements :
* Element (a) is used for shortcut display in menus (display="True") and contains the gdk_keyval_name of the shortcut key
* Element (b) is used in shortcut lookup and contains an uppercase version of the gdk_keyval_name,
* or a gdk_keyval_name name and the "Shift" modifier for Shift altered hardware code keys (see get_group0_keyval() for explanation)
*/
void sp_shortcut_delete_from_file(char const * /*action*/, unsigned int const shortcut) {
@@ -485,7 +485,7 @@ void sp_shortcut_file_export_do(char const *exportname) {
* Element (a) is used for shortcut display in menus (display="True") and contains the gdk_keyval_name of the shortcut key
* Element (b) is used in shortcut lookup and contains an uppercase version of the gdk_keyval_name,
- * or a gdk_keyval_name name and the "Shift" modifier for Shift altered hardware code keys (see get_group0_keyval() for explanation)
+ * or a gdk_keyval_name name and the "Shift" modifier for Shift altered hardware code keys (see get_latin_keyval() for explanation)
*/
void sp_shortcut_delete_from_file(char const * /*action*/, unsigned int const shortcut) {